@@ -355,8 +355,10 @@ void openlog(const char *ident, int logopt, int facility)
     ctx.logopt = logopt;
     if (logopt & LOG_CONS)
         fsldebug(L2_LEVEL_WARNING, "ignored unsupported logopt LOG_CONS");
+#ifdef LOG_PERROR
     if (logopt & LOG_PERROR)
         fsldebug(L2_LEVEL_WARNING, "ignored unsupported logopt LOG_PERROR, use l2spec channel \"fd(filedescriptor=2)\" to emulate");
+#endif
     if (logopt & LOG_PID)
         fsldebug(L2_LEVEL_WARNING, "ignored unsupported logopt PID, use l2spec formatter %%P in prefix channel to emulate");
 
@@ -382,10 +384,6 @@ void openlog(const char *ident, int logopt, int facility)
         cp = l2_env_strerror(ctx.l2_env, l2rv); fsldebug(L2_LEVEL_ERROR, "logging failed to register string formatter: %s(%d)\n", cp, l2rv); CU(1); }
     if ((l2rv = l2_env_formatter(ctx.l2_env, 'm', l2_util_fmt_errno, NULL)) != L2_OK) {
         cp = l2_env_strerror(ctx.l2_env, l2rv); fsldebug(L2_LEVEL_ERROR, "logging failed to register errno formatter: %s(%d)\n", cp, l2rv); CU(1); }
-#if 0
-    if ((l2rv = l2_env_settimer(ctx.l2_env, 20)) != L2_OK) { /*FIXME do we need this? -- RSE: no! */
-        cp = l2_env_strerror(ctx.l2_env, l2rv); fsldebug(L2_LEVEL_ERROR, "failed to configure timer: %s(%d)\n", cp, l2rv); CU(1); }
-#endif
     if ((l2rv = l2_channel_create(&ctx.l2_nch, ctx.l2_env, "noop")) != L2_OK) {
         cp = l2_env_strerror(ctx.l2_env, l2rv); fsldebug(L2_LEVEL_ERROR, "logging failed to create noop channel: %s(%d)\n", cp, l2rv); CU(1); }
 
